@@ -36,15 +36,10 @@ eboutSchema = StructType(
 )
 
 
-
-
-
-
-
-
-def edgebetweeness(sparkdf,group="component"):
+def edgebetweeness(sparkdf):
     from pyspark.context import SparkContext, SparkConf
     from pyspark.sql import SparkSession
+
     conf = SparkConf()
     conf.set("spark.sql.execution.arrow.enabled", "true")
     conf.set("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
@@ -52,9 +47,9 @@ def edgebetweeness(sparkdf,group="component"):
 
     @pandas_udf(eboutSchema, PandasUDFType.GROUPED_MAP)
     def ebdf(pdf):
-        src="src"
-        dst="dst"
-        distance="distance"
+        src = "src"
+        dst = "dst"
+        distance = "distance"
 
         srclist = []
         dstlist = []
@@ -70,28 +65,13 @@ def edgebetweeness(sparkdf,group="component"):
             dstlist.append(dst)
             eblist.append(v)
 
-        return pd.DataFrame(
-            zip(srclist, dstlist, eblist), columns=["src", "dst", "eb"]
-        )
+        return pd.DataFrame(zip(srclist, dstlist, eblist), columns=["src", "dst", "eb"])
 
-    out=sparkdf.groupby(group).apply(ebdf)
+    out = sparkdf.groupby("component").apply(ebdf)
     return out
 
 
-
-bridgesoutSchema = StructType(
-    [
-        StructField("src", StringType()),
-        StructField("dst", StringType()),
-        StructField("weight", DoubleType()),
-        StructField("component", LongType()),
-        StructField("distance", DoubleType()),
-    ]
-)
-
-
-@pandas_udf(bridgesoutSchema, PandasUDFType.GROUPED_MAP)
-def bridgesgroupedmap(sparkdf,group="component"):
+def bridgesgroupedmap(sparkdf):
 
     """
 
@@ -126,8 +106,19 @@ output spark dataframe:
 
     """
 
+    bridgesoutSchema = StructType(
+        [
+            StructField("src", StringType()),
+            StructField("dst", StringType()),
+            StructField("weight", DoubleType()),
+            StructField("component", LongType()),
+            StructField("distance", DoubleType()),
+        ]
+    )
+
+    @pandas_udf(bridgesoutSchema, PandasUDFType.GROUPED_MAP)
     def br_p_udf(pdf):
-    
+
         nxGraph = nx.Graph()
         nxGraph = nx.from_pandas_edgelist(pdf, "src", "dst", "distance")
 
@@ -135,20 +126,12 @@ output spark dataframe:
         bpdf = pd.DataFrame(b, columns=["src", "dst",])
 
         return pd.merge(bpdf, pdf, how="inner", on=["src", "dst"])
-    
-    out = sparkdf.groupby(group).apply(br_p_udf)
+
+    out = sparkdf.groupby("component").apply(br_p_udf)
     return out
 
 
-ecschema = StructType(
-    [
-        StructField("node", StringType()),
-        StructField("eigen_centrality", DoubleType()),
-    ]
-)
-
-@pandas_udf(ecschema, PandasUDFType.GROUPED_MAP)
-def eigencentrality(pdf,group="component"):
+def eigencentrality(sparkdf):
 
     """
     
@@ -198,32 +181,29 @@ output spark dataframe:
    
 
     """
+    ecschema = StructType(
+        [
+            StructField("node", StringType()),
+            StructField("eigen_centrality", DoubleType()),
+        ]
+    )
+
+    @pandas_udf(ecschema, PandasUDFType.GROUPED_MAP)
     def eigenc(pdf):
         nxGraph = nx.Graph()
         nxGraph = nx.from_pandas_edgelist(pdf, "src", "dst", "distance")
         ec = eigenvector_centrality(nxGraph)
         return (
-        pd.DataFrame.from_dict(
-            ec, orient="index", columns=["eigen_centrality"]
+            pd.DataFrame.from_dict(ec, orient="index", columns=["eigen_centrality"])
+            .reset_index()
+            .rename(columns={"index": "node", "eigen_centrality": "eigen_centrality"})
         )
-        .reset_index()
-        .rename(
-            columns={"index": "node", "eigen_centrality": "eigen_centrality"}
-                )
-                )
-    out = sparkdf.groupby(group).apply(eigenc)
+
+    out = sparkdf.groupby("component").apply(eigenc)
     return out
-    
 
 
-hcschema = StructType(
-    [
-        StructField("node", StringType()),
-        StructField("harmonic_centrality", DoubleType()),
-    ]
-)
-@pandas_udf(hcschema, PandasUDFType.GROUPED_MAP)
-def harmoniccentrality(sparkdf,group="component"):
+def harmoniccentrality(sparkdf):
 
     """
 
@@ -269,39 +249,31 @@ output spark dataframe:
 +----+-------------------+
     """
 
+    hcschema = StructType(
+        [
+            StructField("node", StringType()),
+            StructField("harmonic_centrality", DoubleType()),
+        ]
+    )
+
+    @pandas_udf(hcschema, PandasUDFType.GROUPED_MAP)
     def harmc(pdf):
         nxGraph = nx.Graph()
         nxGraph = nx.from_pandas_edgelist(pdf, "src", "dst", "distance")
         hc = harmonic_centrality(nxGraph)
         return (
-            pd.DataFrame.from_dict(
-                hc, orient="index", columns=["harmonic_centrality"]
-            )
+            pd.DataFrame.from_dict(hc, orient="index", columns=["harmonic_centrality"])
             .reset_index()
             .rename(
-                columns={
-                    "index": "node",
-                    "harmonic_centrality": "harmonic_centrality",
-                }
+                columns={"index": "node", "harmonic_centrality": "harmonic_centrality",}
             )
         )
-    
-    out = sparkdf.groupby(group).apply(harmc)
+
+    out = sparkdf.groupby("component").apply(harmc)
     return out
 
 
-@pandas_udf(
-    StructType(
-        [
-            StructField("component", LongType()),
-            StructField("diameter", IntegerType()),
-            StructField("radius", IntegerType()),
-            StructField("transitivity", FloatType()),
-        ]
-    ),
-    functionType=PandasUDFType.GROUPED_MAP,
-)
-def diameter_radius_transitivity(sparkdf,group="component"):
+def diameter_radius_transitivity(sparkdf):
     """    
 
     input spark dataframe:
@@ -332,8 +304,20 @@ def diameter_radius_transitivity(sparkdf,group="component"):
 
 
     """
+
+    @pandas_udf(
+        StructType(
+            [
+                StructField("component", LongType()),
+                StructField("diameter", IntegerType()),
+                StructField("radius", IntegerType()),
+                StructField("transitivity", FloatType()),
+            ]
+        ),
+        functionType=PandasUDFType.GROUPED_MAP,
+    )
     def drt(pdf):
-        
+
         nxGraph = nx.Graph()
         nxGraph = nx.from_pandas_edgelist(pdf, "src", "dst")
         d = diameter(nxGraph)
@@ -347,5 +331,5 @@ def diameter_radius_transitivity(sparkdf,group="component"):
             columns=["component", "diameter", "radius", "transitivity"],
         )
 
-    out = sparkdf.groupby(group).apply(drt)
-    return out
\ No newline at end of file
+    out = sparkdf.groupby("component").apply(drt)
+    return out
